==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sr_Cyrl_BA.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sr_Cyrl_BA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "\u0441\u0432\u0438\u0458\u0435\u0442" },
            { "003", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u0438 \u043a\u043e\u043d\u0442\u0438\u043d\u0435\u043d\u0442" },
            { "015", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "019", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0438 \u0408\u0443\u0436\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "021", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "154", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "AC", "\u043e\u0441\u0442\u0440\u0432\u043e \u0410\u0441\u0435\u043d\u0441\u0438\u043e\u043d" },
            { "BY", "\u0411\u0458\u0435\u043b\u043e\u0440\u0443\u0441\u0438\u0458\u0430" },
            { "CC", "\u041a\u043e\u043a\u043e\u0441\u043e\u0432\u0430 (\u041a\u0438\u043b\u0438\u043d\u0433) \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "CG", "\u041a\u043e\u043d\u0433\u043e" },
            { "CP", "\u043e\u0441\u0442\u0440\u0432\u043e \u041a\u043b\u0438\u043f\u0435\u0440\u0442\u043e\u043d" },
            { "CV", "\u041a\u0430\u0431\u043e \u0412\u0435\u0440\u0434\u0435" },
            { "CZ", "\u0427\u0435\u0448\u043a\u0430 \u0420\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430" },
            { "DE", "\u040a\u0435\u043c\u0430\u0447\u043a\u0430" },
            { "GS", "\u0408\u0443\u0436\u043d\u0430 \u040f\u043e\u0440\u045f\u0438\u0458\u0430 \u0438 \u0408\u0443\u0436\u043d\u0430 \u0421\u0435\u043d\u0434\u0432\u0438\u0447\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "GU", "\u0413\u0432\u0430\u043c" },
            { "HK", "\u0425\u043e\u043d\u0433\u043a\u043e\u043d\u0433 (\u0421\u0410\u041e \u041a\u0438\u043d\u0435)" },
            { "HM", "\u043e\u0441\u0442\u0440\u0432\u043e \u0425\u0435\u0440\u0434 \u0438 \u043e\u0441\u0442\u0440\u0432\u0430 \u041c\u0430\u043a\u0434\u043e\u043d\u0430\u043b\u0434" },
            { "KN", "\u0421\u0432\u0435\u0442\u0438 \u041a\u0438\u0442\u0441 \u0438 \u041d\u0435\u0432\u0438\u0441" },
            { "KP", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041a\u043e\u0440\u0435\u0458\u0430" },
            { "MK", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u0458\u0430" },
            { "MO", "\u0421\u0410\u0420 \u041c\u0430\u043a\u0430\u043e" },
            { "MP", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u0440\u0438\u0458\u0430\u043d\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "NF", "\u043e\u0441\u0442\u0440\u0432\u043e \u041d\u043e\u0440\u0444\u043e\u043a" },
            { "NU", "\u041d\u0438\u0458\u0443\u0435" },
            { "PM", "\u0421\u0432\u0435\u0442\u0438 \u041f\u0458\u0435\u0440 \u0438 \u041c\u0438\u043a\u0435\u043b\u043e\u043d" },
            { "PS", "\u043f\u0430\u043b\u0435\u0441\u0442\u0438\u043d\u0441\u043a\u0435 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u0458\u0435" },
            { "RE", "\u0420\u0435\u0443\u043d\u0438\u043e\u043d" },
            { "UM", "\u0421\u043f\u043e\u0459\u043d\u0430 \u043e\u0441\u0442\u0440\u0432\u0430 \u0421\u0410\u0414" },
            { "VC", "\u0421\u0432\u0435\u0442\u0438 \u0412\u0438\u043d\u0441\u0435\u043d\u0442 \u0438 \u0413\u0440\u0435\u043d\u0430\u0434\u0438\u043d\u0438" },
            { "VG", "\u0411\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430 \u0414\u0458\u0435\u0432\u0438\u0447\u0430\u043d\u0441\u043a\u0430 \u041e\u0441\u0442\u0440\u0432\u0430" },
            { "VI", "\u0410\u043c\u0435\u0440\u0438\u0447\u043a\u0430 \u0414\u0458\u0435\u0432\u0438\u0447\u0430\u043d\u0441\u043a\u0430 \u041e\u0441\u0442\u0440\u0432\u0430" },
            { "be", "\u0431\u0458\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0438" },
            { "bm", "\u0431\u0430\u043c\u0430\u043d\u0430\u043d\u043a\u0430\u043d" },
            { "bn", "\u0431\u0430\u043d\u0433\u043b\u0430" },
            { "de", "\u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "ht", "\u0445\u0430\u0438\u045b\u0430\u043d\u0441\u043a\u0438 \u043a\u0440\u0435\u043e\u043b\u0441\u043a\u0438" },
            { "lo", "\u043b\u0430\u043e\u0448\u043a\u0438" },
            { "nd", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u043d\u0434\u0435\u0431\u0435\u043b\u0435" },
            { "se", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u0441\u0430\u043c\u0438" },
            { "si", "\u0441\u0438\u043d\u0445\u0430\u043b\u0441\u043a\u0438" },
            { "xh", "\u0438\u0441\u0438\u043a\u043e\u0441\u0430" },
            { "zu", "\u0438\u0441\u0438\u0437\u0443\u043b\u0443" },
            { "arn", "\u043c\u0430\u043f\u0443\u0434\u0443\u043d\u0433\u0443\u043d" },
            { "gsw", "\u045a\u0435\u043c\u0430\u0447\u043a\u0438 (\u0428\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0430)" },
            { "lrc", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u043b\u0443\u0440\u0438" },
            { "moh", "\u043c\u043e\u0445\u043e\u043a" },
            { "nds", "\u043d\u0438\u0441\u043a\u043e\u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "nqo", "\u043d\u2019\u043a\u043e" },
            { "shi", "\u0458\u0443\u0436\u043d\u0438 \u0448\u0438\u043b\u0445\u0430" },
            { "tzm", "\u0446\u0435\u043d\u0442\u0440\u0430\u043b\u043d\u043e\u0430\u0442\u043b\u0430\u0441\u043a\u0438 \u0442\u0430\u043c\u0430\u0448\u0435\u043a" },
            { "zgh", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u0438 \u043c\u0430\u0440\u043e\u043a\u0430\u043d\u0441\u043a\u0438 \u0442\u0430\u043c\u0430\u0448\u0435\u043a" },
            { "de_CH", "\u0448\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0438 \u0432\u0438\u0441\u043e\u043a\u0438 \u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "key.co", "\u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "key.ms", "\u0441\u0438\u0441\u0442\u0435\u043c \u043c\u0458\u0435\u0440\u043d\u0438\u0445 \u0458\u0435\u0434\u0438\u043d\u0438\u0446\u0430" },
            { "type.nu.mymr", "\u043c\u0458\u0430\u043d\u043c\u0430\u0440\u0441\u043a\u0435 \u0446\u0438\u0444\u0440\u0435" },
            { "type.co.ducet", "\u043f\u043e\u0434\u0440\u0430\u0437\u0443\u043c\u0438\u0458\u0435\u0432\u0430\u043d\u0438 Unicode \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "type.co.search", "\u043f\u0440\u0435\u0442\u0440\u0430\u0433\u0430 \u043e\u043f\u0448\u0442\u0435 \u043d\u0430\u043c\u0458\u0435\u043d\u0435" },
            { "type.co.standard", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u0438 \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
        };
        return data;
    }
}

==> openjdk-src-23.0.1.u0-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sr_Cyrl_BA.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sr_Cyrl_BA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "\u0441\u0432\u0438\u0458\u0435\u0442" },
            { "003", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0430\u043c\u0435\u0440\u0438\u0447\u043a\u0438 \u043a\u043e\u043d\u0442\u0438\u043d\u0435\u043d\u0442" },
            { "015", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u0444\u0440\u0438\u043a\u0430" },
            { "019", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0438 \u0408\u0443\u0436\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "021", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0410\u043c\u0435\u0440\u0438\u043a\u0430" },
            { "154", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u0415\u0432\u0440\u043e\u043f\u0430" },
            { "AC", "\u043e\u0441\u0442\u0440\u0432\u043e \u0410\u0441\u0435\u043d\u0441\u0438\u043e\u043d" },
            { "AX", "\u041e\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "BL", "\u0421\u0435\u043d \u0411\u0430\u0440\u0442\u0435\u043b\u0435\u043c\u0438" },
            { "BN", "\u0411\u0440\u0443\u043d\u0435\u0458\u0438" },
            { "BV", "\u043e\u0441\u0442\u0440\u0432\u043e \u0411\u0443\u0432\u0435" },
            { "BY", "\u0411\u0458\u0435\u043b\u043e\u0440\u0443\u0441\u0438\u0458\u0430" },
            { "CC", "\u041a\u043e\u043a\u043e\u0441\u043e\u0432\u0430 (\u041a\u0438\u043b\u0438\u043d\u0433) \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "CP", "\u043e\u0441\u0442\u0440\u0432\u043e \u041a\u043b\u0438\u043f\u0435\u0440\u0442\u043e\u043d" },
            { "CZ", "\u0427\u0435\u0448\u043a\u0430 \u0420\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0430" },
            { "DE", "\u040a\u0435\u043c\u0430\u0447\u043a\u0430" },
            { "FK", "\u0424\u043e\u043a\u043b\u0430\u043d\u0434\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "FO", "\u0424\u0430\u0440\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "GS", "\u0408\u0443\u0436\u043d\u0430 \u040f\u043e\u0440\u045f\u0438\u0458\u0430 \u0438 \u0408\u0443\u0436\u043d\u0430 \u0421\u0435\u043d\u0434\u0432\u0438\u0447\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "GU", "\u0413\u0432\u0430\u043c" },
            { "GW", "\u0413\u0432\u0438\u043d\u0435\u0458\u0430 \u0411\u0438\u0441\u0430\u043e" },
            { "HK", "\u0425\u043e\u043d\u0433\u043a\u043e\u043d\u0433 (\u0421\u0410\u041e \u041a\u0438\u043d\u0435)" },
            { "HM", "\u043e\u0441\u0442\u0440\u0432\u043e \u0425\u0435\u0440\u0434 \u0438 \u043e\u0441\u0442\u0440\u0432\u0430 \u041c\u0430\u043a\u0434\u043e\u043d\u0430\u043b\u0434" },
            { "KM", "\u041a\u043e\u043c\u043e\u0440\u0438" },
            { "KP", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041a\u043e\u0440\u0435\u0458\u0430" },
            { "MK", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u0458\u0430" },
            { "MM", "\u041c\u0458\u0430\u043d\u043c\u0430\u0440 (\u0411\u0443\u0440\u043c\u0430)" },
            { "MP", "\u0421\u0458\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u0440\u0438\u0458\u0430\u043d\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "NF", "\u043e\u0441\u0442\u0440\u0432\u043e \u041d\u043e\u0440\u0444\u043e\u043a" },
            { "NU", "\u041d\u0438\u0458\u0443\u0435" },
            { "PS", "\u043f\u0430\u043b\u0435\u0441\u0442\u0438\u043d\u0441\u043a\u0435 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u0458\u0435" },
            { "RE", "\u0420\u0435\u0443\u043d\u0438\u043e\u043d" },
            { "TF", "\u0424\u0440\u0430\u043d\u0446\u0443\u0441\u043a\u0435 \u0458\u0443\u0436\u043d\u0435 \u0442\u0435\u0440\u0438\u0442\u043e\u0440\u0438\u0458\u0435" },
            { "UM", "\u0421\u043f\u043e\u0459\u043d\u0430 \u043e\u0441\u0442\u0440\u0432\u0430 \u0421\u0410\u0414" },
            { "VC", "\u0421\u0432\u0435\u0442\u0438 \u0412\u0438\u043d\u0441\u0435\u043d\u0442 \u0438 \u0413\u0440\u0435\u043d\u0430\u0434\u0438\u043d\u0438" },
            { "VG", "\u0411\u0440\u0438\u0442\u0430\u043d\u0441\u043a\u0430 \u0414\u0458\u0435\u0432\u0438\u0447\u0430\u043d\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "VI", "\u0410\u043c\u0435\u0440\u0438\u0447\u043a\u0430 \u0414\u0458\u0435\u0432\u0438\u0447\u0430\u043d\u0441\u043a\u0430 \u043e\u0441\u0442\u0440\u0432\u0430" },
            { "be", "\u0431\u0458\u0435\u043b\u043e\u0440\u0443\u0441\u043a\u0438" },
            { "bm", "\u0431\u0430\u043c\u0430\u043d\u0430\u043d\u043a\u0430\u043d" },
            { "bn", "\u0431\u0430\u043d\u0433\u043b\u0430" },
            { "de", "\u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "ht", "\u0445\u0430\u0438\u045b\u0430\u043d\u0441\u043a\u0438 \u043a\u0440\u0435\u043e\u043b\u0441\u043a\u0438" },
            { "nd", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u043d\u0434\u0435\u0431\u0435\u043b\u0435" },
            { "se", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u0441\u0430\u043c\u0438" },
            { "crl", "\u0441\u0458\u0435\u0432\u0435\u0440\u043e\u0438\u0441\u0442\u043e\u0447\u043d\u0438 \u043a\u0440\u0438" },
            { "frr", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u043e\u0444\u0440\u0438\u0437\u0438\u0458\u0441\u043a\u0438" },
            { "gsw", "\u045a\u0435\u043c\u0430\u0447\u043a\u0438 (\u0428\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0430)" },
            { "lrc", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u043b\u0443\u0440\u0438" },
            { "nds", "\u043d\u0438\u0441\u043a\u043e\u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "nso", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u0441\u043e\u0442\u043e" },
            { "ojb", "\u0441\u0458\u0435\u0432\u0435\u0440\u043e\u0437\u0430\u043f\u0430\u0434\u043d\u0438 \u043e\u045f\u0438\u0431\u0432\u0430" },
            { "ttm", "\u0441\u0458\u0435\u0432\u0435\u0440\u043d\u0438 \u0442\u0443\u0447\u043e\u043d" },
            { "de_CH", "\u0448\u0432\u0430\u0458\u0446\u0430\u0440\u0441\u043a\u0438 \u0432\u0438\u0441\u043e\u043a\u0438 \u045a\u0435\u043c\u0430\u0447\u043a\u0438" },
            { "key.co", "\u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "key.ms", "\u0441\u0438\u0441\u0442\u0435\u043c \u043c\u0458\u0435\u0440\u043d\u0438\u0445 \u0458\u0435\u0434\u0438\u043d\u0438\u0446\u0430" },
            { "type.nu.mymr", "\u043c\u0458\u0430\u043d\u043c\u0430\u0440\u0441\u043a\u0435 \u0446\u0438\u0444\u0440\u0435" },
            { "type.co.ducet", "\u043f\u043e\u0434\u0440\u0430\u0437\u0443\u043c\u0438\u0458\u0435\u0432\u0430\u043d\u0438 Unicode \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "type.co.compat", "\u043f\u0440\u0435\u0442\u0445\u043e\u0434\u043d\u0438 \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430, \u0437\u0431\u043e\u0433 \u043a\u043e\u043c\u043f\u0430\u0442\u0438\u0431\u0438\u043b\u043d\u043e\u0441\u0442\u0438" },
            { "type.co.search", "\u043f\u0440\u0435\u0442\u0440\u0430\u0433\u0430 \u043e\u043f\u0448\u0442\u0435 \u043d\u0430\u043c\u0458\u0435\u043d\u0435" },
            { "type.co.unihan", "\u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430 \u0440\u0430\u0434\u0438\u043a\u0430\u043b\u043d\u0438\u0445 \u043f\u043e\u0442\u0435\u0437\u0430" },
            { "type.co.phonetic", "\u0444\u043e\u043d\u0435\u0442\u0441\u043a\u0438 \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "type.co.standard", "\u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0434\u043d\u0438 \u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430" },
            { "type.co.dictionary", "\u0440\u0435\u0434\u043e\u0441\u043b\u0438\u0458\u0435\u0434 \u0441\u043e\u0440\u0442\u0438\u0440\u0430\u045a\u0430 \u0443 \u0440\u0458\u0435\u0447\u043d\u0438\u043a\u0443" },
        };
        return data;
    }
}
